*******
Roadmap
*******

cocotb is under development;
however there is no "master plan".
We depend upon users to contribute new features and improvements
while maintainers focus mostly on reviewing PRs, project management, and bugfixes.
Releases will occur approximately every 6 months.

We use GitHub issues to track our pending tasks.
Take a look at the `open feature list <https://github.com/cocotb/cocotb/issues?q=is%3Aissue+is%3Aopen+label%3Atype%3Afeature>`_ to see the work that's lined up,
or the `list of good first issues <https://github.com/cocotb/cocotb/issues?q=is%3Aissue+is%3Aopen+label%3A%22good+first+issue%22>`_ to get your feet wet.

If you have a GitHub account you can also `raise an enhancement request <https://github.com/cocotb/cocotb/issues/new>`_ to suggest new features.

You may be interested in discussions about `planned deprecations <https://github.com/cocotb/cocotb/issues?q=is%3Aopen+label%3Atype%3Adeprecation>`_
or review the `list of already applied deprecations <https://github.com/cocotb/cocotb/issues?q=is%3Aclosed+label%3Atype%3Adeprecation>`_.
